---------------------------------------------------------------------------
-- Voxelis - Voxel survival sandbox for Luanti
-- Copyright (C) 2024 Mad Star Studio LLC
-- 
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 3 of the License, or
-- (at your option) any later version.
--
-- You should have received a copy of the GNU General Public License along
-- with this program; if not, see <http://www.gnu.org/licenses/>.
---------------------------------------------------------------------------

-- This file is intended as the primary entry point for the game.

-- Grass Block
core.register_node("vox_main:grass", {
    description = "Grass Block",
    tiles = {"vox_grass.png"},
    groups = {cracky = 3}
})
core.register_alias("grass", "vox_main:grass")

core.register_biome({
    name = "grassland",
    node_top = "vox_main:grass",
    depth_top = 1,
    node_filler = "vox_main:grass",
    depth_filler = 3,
    node_stone = "vox_main:grass",
    height_min = 1,
    height_max = 4,
    heat_point = 50,
    humidity_point = 50
})

-- Stone
core.register_node("vox_main:stone", {
    description = "Stone",
    tiles = {"vox_stone.png"},
    groups = {cracky = 2}
})
core.register_alias("stone", "vox_main:stone")

core.register_biome({
    name = "stone",
    node_top = "vox_main:stone",
    depth_top = 1,
    node_filler = "vox_main:stone",
    depth_filler = 3,
    node_stone = "vox_main:stone",
    height_min = -31000,
    height_max = 1,
    heat_point = 50,
    humidity_point = 50
})

-- Water
core.register_node("vox_main:water_source", {
    description = "Water Source",
    drawtype = "liquid",
    tiles = {
        {
            name = "vox_water.png",
            animation = {
                type = "vertical_frames",
                aspect_w = 16,
                aspect_h = 16,
                length = 2.0
            }
        }
    },
    alpha = 160,
    paramtype = "light",
    walkable = false,
    pointable = false,
    diggable = false,
    buildable_to = true,
    liquidtype = "source",
    liquid_alternative_flowing = "vox_main:water_flowing",
    liquid_alternative_source = "vox_main:water_source",
    liquid_viscosity = 1,
    post_effect_color = {a = 103, r = 30, g = 60, b = 90}
})
core.register_alias("water_source", "vox_main:water_source")

core.register_node("vox_main:water_flowing", {
    description = "Flowing Water",
    drawtype = "flowingliquid",
    tiles = {"vox_water.png"},
    special_tiles = {
        {
            name = "vox_water.png",
            backface_culling = false,
            animation = {
                type = "vertical_frames",
                aspect_w = 16,
                aspect_h = 16,
                length = 0.8
            }
        }
    },
    alpha = 160,
    paramtype = "light",
    walkable = false,
    pointable = false,
    diggable = false,
    buildable_to = true,
    liquidtype = "flowing",
    liquid_alternative_flowing = "vox_main:water_flowing",
    liquid_alternative_source = "vox_main:water_source",
    liquid_viscosity = 1,
    post_effect_color = {a = 103, r = 30, g = 60, b = 90}
})
core.register_alias("water_flowing", "vox_main:water_flowing")